From: Jan Wielkiewicz <tona_kosmicznego_smiecia@interia.pl>
To: 40677@debbugs.gnu.org
Cc: Jan Wielkiewicz <tona_kosmicznego_smiecia@interia.pl>
Subject: [bug#40677] [PATCH V3 03/15] gnu: jami.scm: Add and use a generalized procedure for applying patches to Jami dependencies.
Date: Sat, 2 May 2020 03:14:38 +0200 [thread overview]
Message-ID: <20200502011450.2676-4-tona_kosmicznego_smiecia@interia.pl> (raw)
In-Reply-To: <20200502011450.2676-1-tona_kosmicznego_smiecia@interia.pl>
* gnu/packages/jami.scm
(jami-apply-dependency-patches): Add procedure.
(pjproject-jami)[arguments]: Use it. Remove the old one.
[native-inputs]: Rename the source to sfl-patches
in order to satisfy the procedure.
---
gnu/packages/jami.scm | 80 ++++++++++++++++++++++++-------------------
1 file changed, 45 insertions(+), 35 deletions(-)
diff --git a/gnu/packages/jami.scm b/gnu/packages/jami.scm
index 44a57c9bfb..2bee3ac143 100644
--- a/gnu/packages/jami.scm
+++ b/gnu/packages/jami.scm
@@ -77,12 +77,31 @@
(base32
"0kw172w2ccyz438kf5xqw14nhfm4xk6a2libnzib9j2wvhlpf4q0"))))
+;; Savoir-Faire Linux modifies many libraries to add features
+;; to Jami. This procedure makes applying patches to a given
+;; package easy.
+(define jami-apply-dependency-patches
+ '(lambda* (#:key inputs dep-name patches)
+ (let ((patches-directory "sfl-patches"))
+ (mkdir-p patches-directory)
+ (invoke "tar" "-xvf" (assoc-ref inputs "sfl-patches")
+ "-C" patches-directory
+ "--strip-components=5"
+ (string-append "ring-project/daemon/contrib/src/"
+ dep-name))
+ (for-each
+ (lambda (file)
+ (invoke "patch" "--force" "-p1" "-i"
+ (string-append patches-directory "/"
+ file ".patch")))
+ patches))))
+
(define-public pjproject-jami
(package
(inherit pjproject)
(name "pjproject-jami")
(native-inputs
- `(("savoir-faire-linux-patches" ,(jami-source))
+ `(("sfl-patches" ,(jami-source))
,@(package-native-inputs pjproject)))
(arguments
`(#:tests? #f
@@ -124,40 +143,31 @@
#t))
(add-after 'unpack 'apply-patches
(lambda* (#:key inputs #:allow-other-keys)
- (let ((savoir-faire-linux-patches-directory "Savoir-faire Linux patches")
- ;; Comes from
- ;; "ring-project/daemon/contrib/src/pjproject/rules.mak".
- ;; WARNING: These amount for huge changes in pjproject.
- (savoir-faire-linux-patches
- '("fix_turn_alloc_failure"
- "rfc2466"
- "ipv6"
- "multiple_listeners"
- "pj_ice_sess"
- "fix_turn_fallback"
- "fix_ioqueue_ipv6_sendto"
- "add_dtls_transport"
- "rfc6544"
- "ice_config"
- "sip_config"
- "fix_first_packet_turn_tcp"
- "fix_ebusy_turn"
- "ignore_ipv6_on_transport_check"
- "fix_turn_connection_failure"
- ;; "uwp_vs" ; for windows
- "disable_local_resolution")))
- (mkdir-p savoir-faire-linux-patches-directory)
- (invoke "tar" "-xvf" (assoc-ref inputs "savoir-faire-linux-patches")
- "-C" savoir-faire-linux-patches-directory
- "--strip-components=5"
- "ring-project/daemon/contrib/src/pjproject")
- (for-each
- (lambda (file)
- (invoke "patch" "--force" "-p1" "-i"
- (string-append savoir-faire-linux-patches-directory "/"
- file ".patch")))
- savoir-faire-linux-patches))
- #t))
+ (let ((jami-apply-dependency-patches ,jami-apply-dependency-patches))
+ ;; Comes from
+ ;; "ring-project/daemon/contrib/src/pjproject/rules.mak".
+ ;; WARNING: These amount for huge changes in pjproject.
+ (jami-apply-dependency-patches
+ #:inputs inputs
+ #:dep-name "pjproject"
+ #:patches
+ '("fix_turn_alloc_failure"
+ "rfc2466"
+ "ipv6"
+ "multiple_listeners"
+ "pj_ice_sess"
+ "fix_turn_fallback"
+ "fix_ioqueue_ipv6_sendto"
+ "add_dtls_transport"
+ "rfc6544"
+ "ice_config"
+ "sip_config"
+ "fix_first_packet_turn_tcp"
+ "fix_ebusy_turn"
+ "ignore_ipv6_on_transport_check"
+ "fix_turn_connection_failure"
+ "disable_local_resolution"))
+ #t)))
;; TODO: We could use substitute-keyword-arguments instead of
;; repeating the phases from pjproject, but somehow it does
;; not work.
--
2.26.2
next prev parent reply other threads:[~2020-05-02 1:41 UTC|newest]
Thread overview: 144+ messages / expand[flat|nested] mbox.gz Atom feed top
2020-04-17 0:00 [bug#40677] Jami Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 01/30] gnu: jami: Move Jami and its dependencies to jami.scm Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 02/30] gnu: jami: Bump to 20200203.1.5ee7e10 Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 03/30] gnu: jami: Fix downloading by changing the prefix to "jami_"; Use the "release" dir instead of the deprecated "ring-release" Jan Wielkiewicz
2020-04-18 12:16 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 04/30] gnu: jami: Add a generalized procedure for applying patches made by Savoir-faire linux to Jami dependencies Jan Wielkiewicz
2020-04-18 12:24 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 05/30] gnu: pjproject-jami: Use the jami-apply-dependency-patches procedure Jan Wielkiewicz
2020-04-18 12:27 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 06/30] gnu: Add libnatpmp Jan Wielkiewicz
2020-04-18 12:30 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 07/30] gnu: libring: Add libnatpmp as an optional dependency; remove unnecessary comment Jan Wielkiewicz
2020-04-18 12:33 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 08/30] gnu: libupnp: Bump to 1.8.6; change the download method to git-fetch; add missing dependencies Jan Wielkiewicz
2020-04-18 12:37 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 09/30] gnu: opendht: Bump to 2.0.0rc1 Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 10/30] gnu: Add ffmpeg-jami Jan Wielkiewicz
2020-04-18 12:49 ` Mathieu Othacehe
2020-04-19 20:03 ` Jan
2020-04-17 0:34 ` [bug#40677] [PATCH 11/30] gnu: libring: Use ffmpeg-jami instead of ffmpeg Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 12/30] gnu: restinio: Bump to 0.6.1.1 Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 13/30] gnu: pjproject: Add and apply a patch fixing the crash Jan Wielkiewicz
2020-04-18 12:54 ` Mathieu Othacehe
2020-04-19 22:26 ` Jan
2020-04-17 0:34 ` [bug#40677] [PATCH 14/30] gnu: jami.scm: Add a missing module Jan Wielkiewicz
2020-04-18 12:55 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 15/30] gnu: jami: Bump to 20200206.2.996bf03 Jan Wielkiewicz
2020-04-18 12:56 ` Mathieu Othacehe
2020-04-19 19:49 ` Jan
2020-04-17 0:34 ` [bug#40677] [PATCH 16/30] gnu: pjproject-jami: Add a new SFL patch Jan Wielkiewicz
2020-04-18 13:00 ` Mathieu Othacehe
2020-04-19 19:49 ` Jan
2020-04-19 20:32 ` Michael Rohleder
2020-04-17 0:34 ` [bug#40677] [PATCH 17/30] gnu: pjproject: Fix formatting Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 18/30] gnu: jami: Make gettext a native input Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 19/30] gnu: jami.scm: Untabify by emacs Jan Wielkiewicz
2020-04-18 13:08 ` Mathieu Othacehe
2020-04-17 0:34 ` [bug#40677] [PATCH 20/30] gnu: jami: Bump to 20200214.1.7488e86 Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 21/30] gnu: opendht: Bump to 2.0.0rc2 Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 22/30] gnu: networking.scm: Add missing copyright year Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 23/30] gnu: pjproject, pjproject-jami: Remove broken pjproject package. Make pjproject-jami package stand-alone by moving package code from pjproject into it Jan Wielkiewicz
2020-04-18 13:03 ` Mathieu Othacehe
2020-04-19 19:44 ` Jan
2020-04-17 0:34 ` [bug#40677] [PATCH 24/30] gnu: jami: Bump to 20200326.1.f8d3d10 Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 25/30] gnu: pjproject-jami: Bump to 2.10; apply some cool patches Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 26/30] gnu: jami.scm: Indent code properly Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 27/30] gnu: opendht: Bump to 2.0.0 Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 28/30] gnu: jami: Bump to 20200401.1.6f090de Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 29/30] gnu: jami: Replace gnu-gettext with gettext-minimal, just like on master Jan Wielkiewicz
2020-04-17 0:34 ` [bug#40677] [PATCH 30/30] gnu: pjproject-jami: Add the missing "--enable-epoll" flag Jan Wielkiewicz
2020-04-18 13:13 ` Mathieu Othacehe
2020-04-18 12:13 ` [bug#40677] [PATCH 01/30] gnu: jami: Move Jami and its dependencies to jami.scm Mathieu Othacehe
2020-04-20 22:55 ` [bug#40677] Code review problems resolved Jan
2020-04-21 7:04 ` Christopher Baines
2020-04-21 7:28 ` Mathieu Othacehe
2020-04-21 16:10 ` [bug#40677] [PATCH 01/18] gnu: jami: Move Jami and its dependencies to jami.scm Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 02/18] gnu: jami: Fix downloading Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 03/18] gnu: jami.scm: Add and use a generalized procedure for applying patches made by Savoir-faire linux to Jami dependencies Jan Wielkiewicz
2020-04-22 9:07 ` Mathieu Othacehe
2020-04-21 16:10 ` [bug#40677] [PATCH 04/18] gnu: Add libnatpmp Jan Wielkiewicz
2020-04-22 9:27 ` Mathieu Othacehe
2020-04-27 22:55 ` Jan
2020-04-28 7:19 ` Mathieu Othacehe
2020-04-29 22:31 ` Jan
2020-04-30 7:04 ` Mathieu Othacehe
2020-04-21 16:10 ` [bug#40677] [PATCH 05/18] gnu: libring: Add libnatpmp as an optional dependency Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 06/18] gnu: libupnp: Bump to 1.8.6; change the download method to git-fetch; add missing dependencies Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 07/18] gnu: Add ffmpeg-jami Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 08/18] gnu: libring: Use ffmpeg-jami instead of ffmpeg Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 09/18] gnu: restinio: Bump to 0.6.1.1 Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 10/18] gnu: pjproject-jami: Add a new SFL patch Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 11/18] gnu: pjproject: Fix formatting Jan Wielkiewicz
2020-04-22 9:32 ` Mathieu Othacehe
2020-04-21 16:10 ` [bug#40677] [PATCH 12/18] gnu: jami: Make gettext a native input Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 13/18] gnu: pjproject, pjproject-jami: Remove broken pjproject package. Make pjproject-jami package stand-alone by moving package code from pjproject into it Jan Wielkiewicz
2020-04-22 9:39 ` Mathieu Othacehe
2020-04-22 11:42 ` Jan
2020-04-21 16:10 ` [bug#40677] [PATCH 14/18] gnu: pjproject-jami: Bump to 2.10, apply new SFL patches Jan Wielkiewicz
2020-04-22 9:40 ` Mathieu Othacehe
2020-04-21 16:10 ` [bug#40677] [PATCH 15/18] gnu: opendht: Bump to 2.0.0 Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 16/18] gnu: jami: Bump to 20200401.1.6f090de Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 17/18] gnu: jami: Replace gnu-gettext with gettext-minimal, just like on master Jan Wielkiewicz
2020-04-21 16:10 ` [bug#40677] [PATCH 18/18] gnu: pjproject-jami: Add the missing, linux-only "--enable-epoll" flag Jan Wielkiewicz
2020-04-22 9:44 ` Mathieu Othacehe
2020-04-22 8:59 ` [bug#40677] [PATCH 01/18] gnu: jami: Move Jami and its dependencies to jami.scm Mathieu Othacehe
2020-04-22 10:42 ` Jan
2020-04-22 11:42 ` Mathieu Othacehe
2020-04-27 23:18 ` Jan
2020-04-28 7:14 ` Mathieu Othacehe
2020-04-22 16:08 ` Christopher Baines
2020-05-02 1:14 ` [bug#40677] [PATCH V3 00/15] Jami patches Jan Wielkiewicz
2020-05-02 1:14 ` [bug#40677] [PATCH V3 01/15] gnu: telephony.scm: Move Jami and its dependencies to jami.scm Jan Wielkiewicz
2020-05-02 8:45 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 02/15] gnu: jami: Fix downloading Jan Wielkiewicz
2020-05-02 8:47 ` Mathieu Othacehe
2020-05-02 1:14 ` Jan Wielkiewicz [this message]
2020-05-02 8:54 ` [bug#40677] [PATCH V3 03/15] gnu: jami.scm: Add and use a generalized procedure for applying patches to Jami dependencies Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 04/15] gnu: Add libnatpmp Jan Wielkiewicz
2020-05-02 8:22 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 05/15] gnu: libring: Add libnatpmp as an optional dependency Jan Wielkiewicz
2020-05-02 8:56 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 06/15] gnu: libupnp: Bump to 1.8.6 Jan Wielkiewicz
2020-05-02 8:30 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 07/15] gnu: Add ffmpeg-jami Jan Wielkiewicz
2020-05-02 9:36 ` Mathieu Othacehe
2020-05-02 11:31 ` Jan
2020-05-04 18:26 ` Jan
2020-05-05 7:18 ` Mathieu Othacehe
2020-05-07 0:22 ` Jan
2020-05-08 8:43 ` Mathieu Othacehe
2020-05-07 20:03 ` Jan
2020-05-08 8:35 ` Mathieu Othacehe
2020-05-13 14:57 ` Jan
2020-05-13 15:51 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 08/15] gnu: libring: Use ffmpeg-jami instead of ffmpeg Jan Wielkiewicz
2020-05-02 1:14 ` [bug#40677] [PATCH V3 09/15] gnu: restinio: Bump to 0.6.1.1 Jan Wielkiewicz
2020-05-02 8:32 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 10/15] gnu: jami: Make gettext a native input Jan Wielkiewicz
2020-05-02 8:58 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 11/15] gnu: pjproject, pjproject-jami: Bump to 2.10, apply new SFL patches Jan Wielkiewicz
2020-05-02 9:14 ` Mathieu Othacehe
2020-05-02 15:17 ` Jan
2020-05-02 1:14 ` [bug#40677] [PATCH V3 12/15] gnu: jami: Bump to 20200401.1.6f090de Jan Wielkiewicz
2020-05-02 9:19 ` Mathieu Othacehe
2020-05-02 11:33 ` Jan
2020-05-02 9:25 ` Mathieu Othacehe
2020-05-02 15:04 ` Jan
2020-05-02 1:14 ` [bug#40677] [PATCH V3 13/15] gnu: jami: Replace gnu-gettext with gettext-minimal, just like on master Jan Wielkiewicz
2020-05-02 9:28 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 14/15] gnu: pjproject-jami: Add the missing, linux-only "--enable-epoll" flag Jan Wielkiewicz
2020-05-02 9:32 ` Mathieu Othacehe
2020-05-02 1:14 ` [bug#40677] [PATCH V3 15/15] gnu: opendht: Bump to 2.0.0 Jan Wielkiewicz
2020-05-02 8:38 ` Mathieu Othacehe
2020-05-02 9:52 ` [bug#40677] [PATCH V3 00/15] Jami patches Mathieu Othacehe
2020-05-02 11:26 ` Jan
2020-05-03 7:34 ` Mathieu Othacehe
2020-05-03 14:32 ` Jan
2020-05-02 14:58 ` Jan
2020-05-13 18:12 ` [bug#40677] [PATCH v4] gnu: Add ffmpeg-jami Jan Wielkiewicz
2020-05-14 7:05 ` Mathieu Othacehe
2020-05-14 12:43 ` Jan
2020-05-15 6:59 ` Mathieu Othacehe
2020-05-15 0:47 ` [bug#40677] [PATCH v5] " Jan Wielkiewicz
2020-05-15 7:11 ` bug#40677: " Mathieu Othacehe
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20200502011450.2676-4-tona_kosmicznego_smiecia@interia.pl \
--to=tona_kosmicznego_smiecia@interia.pl \
--cc=40677@debbugs.gnu.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
Code repositories for project(s) associated with this external index
https://git.savannah.gnu.org/cgit/guix.git
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.